#!/bin/bash
#
# buildGflags.sh 

# if this build script complains that it cannot find bzlib.h, 
# you need to install bzip2-devel on Scientific Linux

usage()
{
   echo "USAGE: `basename ${0}` <product_directory> <e15|e17|e19|c2|c7>  [tar]"
}

# -------------------------------------------------------------------
# shared boilerplate
# -------------------------------------------------------------------

get_this_dir() 
{
    ( cd / ; /bin/pwd -P ) >/dev/null 2>&1
    if (( $? == 0 )); then
      pwd_P_arg="-P"
    fi
    reldir=`dirname ${0}`
    thisdir=`cd ${reldir} && /bin/pwd ${pwd_P_arg}`
}

get_ssibuildshims()
{
    # make sure we can use the setup alias
    if [ -z ${UPS_DIR} ]
    then
       echo "ERROR: please setup ups"
       exit 1
    fi
    source `${UPS_DIR}/bin/ups setup ${SETUP_UPS}`
    
    setup ssibuildshims ${ssibuildshims_version} -z ${product_dir}
    if [ -z ${SSIBUILDSHIMS_DIR} ]
    then
       echo "ERROR: failed to setup ssibuildshims ${ssibuildshims_version}"
       exit 1
    fi
}

# -------------------------------------------------------------------
# start processing
# -------------------------------------------------------------------

product_dir=${1}
basequal=${2}
maketar=${3}

if [ -z ${product_dir} ]
then
   echo "ERROR: please specify the local product directory"
   usage
   exit 1
fi

# -------------------------------------------------------------------
# package name and version
# -------------------------------------------------------------------

package=gflags
origpkgver=v2_2_2
pkgver=${origpkgver}
ssibuildshims_version=v1_04_13
pkgdotver=`echo ${origpkgver} | sed -e 's/_/./g' | sed -e 's/^v//'`
pkgtarname=gflags-${pkgdotver}

get_this_dir

get_ssibuildshims

source define_basics NO_TYPE

if [ "${maketar}" = "tar" ] && [ -d ${pkgdir} ]
then
   ${SSIBUILDSHIMS_DIR}/bin/make_distribution_tarball ${product_dir} ${package} ${pkgver} ${fullqual}
   exit 0
fi

echo "building ${package} for ${OS}-${plat}-${qualdir} (flavor ${flvr})"

# -------------------------------------------------------------------
# package dependent stuff goes here
# -------------------------------------------------------------------

if [[ "${basequal}" == e1[045] ]]
then
  cc=gcc
  cxx=g++
  cxxflg="-std=c++14"
elif [[ "${basequal}" == e1[79] ]]
then
  cc=gcc
  cxx=g++
  cxxflg="-std=c++17"
elif [[ "${basequal}" == c[27] ]]
then
  cc=clang
  cxx=clang++
  cxxflg="-std=c++17"
else
  ssi_die "Qualifier $basequal not recognized."
fi

mkdir -p ${pkgdir}/src
if [ ! -d ${pkgdir}/src ]
then
   echo "ERROR: failed to create ${pkgdir}/src"
   exit 1
fi
mkdir -p ${blddir}                         
if [ ! -d ${blddir} ]                      
then                                       
   echo "ERROR: failed to create ${blddir}"
   exit 1                                  
fi

# declare now so we can setup
# fake ups declare
fakedb=${product_dir}/${package}/${pkgver}/fakedb
${SSIBUILDSHIMS_DIR}/bin/fake_declare_product ${product_dir} ${package} ${pkgver} ${fullqual}

setup -B ${package} ${pkgver} -q ${fullqual} -z ${fakedb}:${product_dir}:${PRODUCTS} || ssi_die "ERROR: fake setup failed"

source ${SSIBUILDSHIMS_DIR}/bin/setup_cmake || ssi_die "ERROR: failed to setup camke"

set -x

cd ${pkgdir}/src
tar xf ${tardir}/${pkgtarname}.tar.gz

cd ${blddir}

env CC=${cc} CXX=${cxx} FC=gfortran cmake \
   -DCMAKE_INSTALL_PREFIX=${pkgdir} \
   -DCMAKE_CXX_FLAGS="${cxxflg} -fPIC" \
   ${pkgdir}/src/${pkgtarname} || ssi_die "cmake failed"
make || ssi_die "ERROR: make failed."
make install || ssi_die "make install failed."

set +x

if [ ! -d ${pkgdir}/lib ]
then
   echo "ERROR: failed to create ${pkgdir}/lib"
   echo "       Something is very wrong"
   exit 1
fi

# real ups declare
${SSIBUILDSHIMS_DIR}/bin/declare_product ${product_dir} ${package} ${pkgver} ${fullqual} || ssi_die "failed to declare ${package} ${pkgver}"

# -------------------------------------------------------------------
# common bottom stuff
# -------------------------------------------------------------------

# this should not complain
echo "Finished building ${package} ${pkgver}"
setup ${package} ${pkgver} -q ${fullqual} -z ${product_dir}:${PRODUCTS}
echo "gflags is installed at ${GFLAGS_FQ_DIR}"

# fixing pkgconfig file
mv ${GFLAGS_FQ_DIR}/lib/pkgconfig/gflags.pc ${GFLAGS_FQ_DIR}/lib/pkgconfig/gflags.pc.bak
cat ${GFLAGS_FQ_DIR}/lib/pkgconfig/gflags.pc.bak | sed "s%${GFLAGS_FQ_DIR}%\${pcfiledir}/../..%g" > ${GFLAGS_FQ_DIR}/lib/pkgconfig/gflags.pc

# this must be last
if [ "${maketar}" = "tar" ] && [ -d ${GFLAGS_FQ_DIR} ]
then
   ${SSIBUILDSHIMS_DIR}/bin/make_distribution_tarball ${product_dir} ${package} ${pkgver} ${fullqual}
fi

exit 0
